@@ -7,15 +7,9 @@ from asdf_astropy.testing.helpers import assert_time_delta_equal
 
 
 def create_time_deltas():
-    result = [
-        TimeDelta([1, 2] * u.day),
-    ]
-
-    for format in TimeDelta.FORMATS.keys():
-        result.append(TimeDelta(Time.now() - Time.now(), format=format))
-
-    for scale in list(TimeDelta.SCALES) + [None]:
-        result.append(TimeDelta(0.125, scale=scale))
+    result = [TimeDelta([1, 2] * u.day)]
+    result += [TimeDelta(Time.now() - Time.now(), format=format_) for format_ in TimeDelta.FORMATS]
+    result += [TimeDelta(0.125 * u.day, scale=scale) for scale in [*list(TimeDelta.SCALES), None]]
 
     return result
 
